# To close budget on particles

The way to close tracer budget on Lagrangian particles involves quite a bit of [math](https://agupubs.onlinelibrary.wiley.com/doi/10.1029/2024MS004848) but I think I have made the software relatively easy to use. You can get started with the [notebook examples](https://macekuailv.github.io/seaduck/bud_tut.html). You can also find the [eulerian_budget](https://macekuailv.github.io/seaduck/api_reference/apiref_eulerian_budget.html) and [lagrangian_budget](https://macekuailv.github.io/seaduck/api_reference/apiref_lagrangian_budget.html).

If you would like to use this functionality but have some difficulties, please email me (Wenrui Jiang) at wrjiang@mit.edu. I am happy to explain things, and potentially get more involved on your project.

If you have suggestions on how to make the budget code more accessible to the wider audience or improve it in other ways, please also email me. I don't know how to thank you enough.
